@@ -13,27 +13,18 @@
 from __future__ import print_function
 
 from reno import formatter
-from reno import scanner
-from reno import utils
+from reno import loader
 
 
-def report_cmd(args):
+def report_cmd(args, conf):
     "Generates a release notes report"
-    reporoot = args.reporoot.rstrip('/') + '/'
-    notesdir = utils.get_notes_dir(args)
-    collapse = args.collapse_pre_releases
-    notes = scanner.get_notes_by_version(
-        reporoot, notesdir, args.branch,
-        collapse_pre_releases=collapse,
-        earliest_version=args.earliest_version,
-    )
+    ldr = loader.Loader(conf)
     if args.version:
         versions = args.version
     else:
-        versions = notes.keys()
+        versions = ldr.versions
     text = formatter.format_report(
-        reporoot,
-        notes,
+        ldr,
         versions,
         title='Release Notes',
     )
